# pynla: Python Numerical Linear Algebra

**🚧 Under Construction 🚧**

`pynla` is a future library for high-performance, GPU-accelerated Numerical Linear Algebra in Python.
It aims to provide state-of-the-art randomized algorithms (RandNLA) and solvers compatible with NumPy, CuPy, and PyTorch via the Array API standard.

**Expected Release:** 2025

*Author: Massimo Fedrigo*